==> eui-76.1.0.tgz: package/lib/components/tabs/tabs.a11y.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _tabbed_content = require("./tabbed_content");

var _spacer = require("../spacer");

var _text = require("../text");

var _react2 = require("@emotion/react");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var tabs = [{
  id: 'cobalt--id',
  name: 'Cobalt',
  content: (0, _react2.jsx)(_react.default.Fragment, null, (0, _react2.jsx)(_spacer.EuiSpacer, null), (0, _react2.jsx)(_text.EuiText, null, (0, _react2.jsx)("p", null, "Cobalt is a chemical element with symbol Co and atomic number 27. Like nickel, cobalt is found in the Earth\u2019s crust only in chemically combined form, save for small deposits found in alloys of natural meteoric iron. The free element, produced by reductive smelting, is a hard, lustrous, silver-gray metal.")))
}, {
  id: 'dextrose--id',
  name: 'Dextrose',
  content: (0, _react2.jsx)(_react.default.Fragment, null, (0, _react2.jsx)(_spacer.EuiSpacer, null), (0, _react2.jsx)(_text.EuiText, null, (0, _react2.jsx)("p", null, "Intravenous sugar solution, also known as dextrose solution, is a mixture of dextrose (glucose) and water. It is used to treat low blood sugar or water loss without electrolyte loss.")))
}, {
  id: 'hydrogen--id',
  name: 'Hydrogen',
  content: (0, _react2.jsx)(_react.default.Fragment, null, (0, _react2.jsx)(_spacer.EuiSpacer, null), (0, _react2.jsx)(_text.EuiText, null, (0, _react2.jsx)("p", null, "Hydrogen is a chemical element with symbol H and atomic number 1. With a standard atomic weight of 1.008, hydrogen is the lightest element on the periodic table")))
}, {
  id: 'monosodium_glutammate--id',
  name: 'Monosodium Glutamate',
  content: (0, _react2.jsx)(_react.default.Fragment, null, (0, _react2.jsx)(_spacer.EuiSpacer, null), (0, _react2.jsx)(_text.EuiText, null, (0, _react2.jsx)("p", null, "Monosodium glutamate (MSG, also known as sodium glutamate) is the sodium salt of glutamic acid, one of the most abundant naturally occurring non-essential amino acids. Monosodium glutamate is found naturally in tomatoes, cheese and other foods.")))
}];
var defaultTabProps = {
  tabs: tabs,
  initialSelectedTab: tabs[0],
  autoFocus: 'selected',
  onTabClick: function onTabClick() {}
};
describe('EuiTabs', function () {
  describe('Automated accessibility check', function () {
    it('has zero violations with default props', function () {
      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, defaultTabProps));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
    it('has zero violations with second tab open on render', function () {
      var secondSelectedTab = _objectSpread(_objectSpread({}, defaultTabProps), {}, {
        initialSelectedTab: tabs[1]
      });

      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, secondSelectedTab));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
    it('has zero violations with third tab open on render', function () {
      var thirdSelectedTab = _objectSpread(_objectSpread({}, defaultTabProps), {}, {
        initialSelectedTab: tabs[2]
      });

      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, thirdSelectedTab));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
    it('has zero violations with last tab open on render', function () {
      var lastSelectedTab = _objectSpread(_objectSpread({}, defaultTabProps), {}, {
        initialSelectedTab: tabs[3]
      });

      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, lastSelectedTab));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
    it('has zero violations with all tabs disabled except first', function () {
      var disabledTabs = tabs.map(function (tab, i) {
        if (i === 0) {
          return tab;
        }

        return _objectSpread(_objectSpread({}, tab), {}, {
          disabled: true
        });
      });

      var disabledTabProps = _objectSpread(_objectSpread({}, defaultTabProps), {}, {
        tabs: disabledTabs
      });

      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, disabledTabProps));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
  });
});

==> eui-95.7.0.tgz: package/lib/components/tabs/tabs.a11y.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));
var _tabbed_content = require("./tabbed_content");
var _spacer = require("../spacer");
var _text = require("../text");
var _react2 = require("@emotion/react");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); } /*
 * Copyright Elasticsearch B.V. and/or licensed to Elasticsearch B.V. under one
 * or more contributor license agreements. Licensed under the Elastic License
 * 2.0 and the Server Side Public License, v 1; you may not use this file except
 * in compliance with, at your election, the Elastic License 2.0 or the Server
 * Side Public License, v 1.
 */ /// <reference types="cypress" />
/// <reference types="cypress-real-events" />
/// <reference types="../../../cypress/support" />
var tabs = [{
  id: 'cobalt--id',
  name: 'Cobalt',
  content: (0, _react2.jsx)(_react.default.Fragment, null, (0, _react2.jsx)(_spacer.EuiSpacer, null), (0, _react2.jsx)(_text.EuiText, null, (0, _react2.jsx)("p", null, "Cobalt is a chemical element with symbol Co and atomic number 27. Like nickel, cobalt is found in the Earth\u2019s crust only in chemically combined form, save for small deposits found in alloys of natural meteoric iron. The free element, produced by reductive smelting, is a hard, lustrous, silver-gray metal.")))
}, {
  id: 'dextrose--id',
  name: 'Dextrose',
  content: (0, _react2.jsx)(_react.default.Fragment, null, (0, _react2.jsx)(_spacer.EuiSpacer, null), (0, _react2.jsx)(_text.EuiText, null, (0, _react2.jsx)("p", null, "Intravenous sugar solution, also known as dextrose solution, is a mixture of dextrose (glucose) and water. It is used to treat low blood sugar or water loss without electrolyte loss.")))
}, {
  id: 'hydrogen--id',
  name: 'Hydrogen',
  content: (0, _react2.jsx)(_react.default.Fragment, null, (0, _react2.jsx)(_spacer.EuiSpacer, null), (0, _react2.jsx)(_text.EuiText, null, (0, _react2.jsx)("p", null, "Hydrogen is a chemical element with symbol H and atomic number 1. With a standard atomic weight of 1.008, hydrogen is the lightest element on the periodic table")))
}, {
  id: 'monosodium_glutammate--id',
  name: 'Monosodium Glutamate',
  content: (0, _react2.jsx)(_react.default.Fragment, null, (0, _react2.jsx)(_spacer.EuiSpacer, null), (0, _react2.jsx)(_text.EuiText, null, (0, _react2.jsx)("p", null, "Monosodium glutamate (MSG, also known as sodium glutamate) is the sodium salt of glutamic acid, one of the most abundant naturally occurring non-essential amino acids. Monosodium glutamate is found naturally in tomatoes, cheese and other foods.")))
}];
var defaultTabProps = {
  tabs: tabs,
  initialSelectedTab: tabs[0],
  autoFocus: 'selected',
  onTabClick: function onTabClick() {}
};
describe('EuiTabs', function () {
  describe('Automated accessibility check', function () {
    it('has zero violations with default props', function () {
      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, defaultTabProps));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
    it('has zero violations with second tab open on render', function () {
      var secondSelectedTab = _objectSpread(_objectSpread({}, defaultTabProps), {}, {
        initialSelectedTab: tabs[1]
      });
      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, secondSelectedTab));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
    it('has zero violations with third tab open on render', function () {
      var thirdSelectedTab = _objectSpread(_objectSpread({}, defaultTabProps), {}, {
        initialSelectedTab: tabs[2]
      });
      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, thirdSelectedTab));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
    it('has zero violations with last tab open on render', function () {
      var lastSelectedTab = _objectSpread(_objectSpread({}, defaultTabProps), {}, {
        initialSelectedTab: tabs[3]
      });
      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, lastSelectedTab));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
    it('has zero violations with all tabs disabled except first', function () {
      var disabledTabs = tabs.map(function (tab, i) {
        if (i === 0) {
          return tab;
        }
        return _objectSpread(_objectSpread({}, tab), {}, {
          disabled: true
        });
      });
      var disabledTabProps = _objectSpread(_objectSpread({}, defaultTabProps), {}, {
        tabs: disabledTabs
      });
      cy.mount((0, _react2.jsx)(_tabbed_content.EuiTabbedContent, disabledTabProps));
      cy.get('div.euiTabs').should('exist');
      cy.checkAxe();
    });
  });
});
